@@ -16,7 +16,7 @@ import (
 
 const demoIP = "1.2.3.4"
 
-func TestNATTypeDefauts(t *testing.T) {
+func TestNATTypeDefaults(t *testing.T) {
 	loggerFactory := logging.NewDefaultLoggerFactory()
 	nat, err := newNAT(&natConfig{
 		natType:       NATType{},
@@ -27,7 +27,7 @@ func TestNATTypeDefauts(t *testing.T) {
 
 	assert.Equal(t, EndpointIndependent, nat.natType.MappingBehavior, "should match")
 	assert.Equal(t, EndpointIndependent, nat.natType.FilteringBehavior, "should match")
-	assert.False(t, nat.natType.Hairpining, "should be false")
+	assert.False(t, nat.natType.Hairpinning, "should be false")
 	assert.False(t, nat.natType.PortPreservation, "should be false")
 	assert.Equal(t, defaultNATMappingLifeTime, nat.natType.MappingLifeTime, "should be false")
 }
@@ -41,7 +41,7 @@ func TestNATMappingBehavior(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointIndependent,
 				FilteringBehavior: EndpointIndependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   30 * time.Second,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -65,9 +65,10 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-original  : %s\n", oic.String())
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-original  : %s", oic.String())
+		log.Debugf("o-translated: %s", oec.String())
 
+		//nolint:forcetypeassert
 		iec := newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -79,13 +80,14 @@ func TestNATMappingBehavior(t *testing.T) {
 			},
 		)
 
-		log.Debugf("i-original  : %s\n", iec.String())
+		log.Debugf("i-original  : %s", iec.String())
 
 		iic, err := nat.translateInbound(iec)
 		assert.Nil(t, err, "should succeed")
 
-		log.Debugf("i-translated: %s\n", iic.String())
+		log.Debugf("i-translated: %s", iic.String())
 
+		//nolint:forcetypeassert
 		assert.Equal(t,
 			oic.SourceAddr().String(),
 			iic.(*chunkUDP).DestinationAddr().String(),
@@ -93,6 +95,7 @@ func TestNATMappingBehavior(t *testing.T) {
 
 		// packet with dest addr that does not exist in the mapping table
 		// will be dropped
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -109,6 +112,7 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.NotNil(t, err, "should fail (dropped)")
 
 		// packet from any addr will be accepted (full-cone)
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -129,7 +133,7 @@ func TestNATMappingBehavior(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointIndependent,
 				FilteringBehavior: EndpointAddrDependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   30 * time.Second,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -147,13 +151,13 @@ func TestNATMappingBehavior(t *testing.T) {
 		}
 
 		oic := newChunkUDP(src, dst)
-		log.Debugf("o-original  : %s\n", oic.String())
+		log.Debugf("o-original  : %s", oic.String())
 
 		oec, err := nat.translateOutbound(oic)
 		assert.Nil(t, err, "should succeed")
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-translated: %s", oec.String())
 
 		// sending different (IP: 5.6.7.9) won't create a new mapping
 		oic2 := newChunkUDP(&net.UDPAddr{
@@ -167,8 +171,9 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.Nil(t, err, "should succeed")
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
-		log.Debugf("o-translated: %s\n", oec2.String())
+		log.Debugf("o-translated: %s", oec2.String())
 
+		//nolint:forcetypeassert
 		iec := newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -180,15 +185,16 @@ func TestNATMappingBehavior(t *testing.T) {
 			},
 		)
 
-		log.Debugf("i-original  : %s\n", iec.String())
+		log.Debugf("i-original  : %s", iec.String())
 
 		iic, err := nat.translateInbound(iec)
 		if !assert.NoError(t, err, "should succeed") {
 			return
 		}
 
-		log.Debugf("i-translated: %s\n", iic.String())
+		log.Debugf("i-translated: %s", iic.String())
 
+		//nolint:forcetypeassert
 		assert.Equal(t,
 			oic.SourceAddr().String(),
 			iic.(*chunkUDP).DestinationAddr().String(),
@@ -196,6 +202,7 @@ func TestNATMappingBehavior(t *testing.T) {
 
 		// packet with dest addr that does not exist in the mapping table
 		// will be dropped
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -212,6 +219,7 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.NotNil(t, err, "should fail (dropped)")
 
 		// packet from any port will be accepted (restricted-cone)
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -226,7 +234,8 @@ func TestNATMappingBehavior(t *testing.T) {
 		_, err = nat.translateInbound(iec)
 		assert.Nil(t, err, "should succeed")
 
-		// packet from different addr will be droped (restricted-cone)
+		// packet from different addr will be dropped (restricted-cone)
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   net.ParseIP("6.6.6.6"),
@@ -248,7 +257,7 @@ func TestNATMappingBehavior(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointIndependent,
 				FilteringBehavior: EndpointAddrPortDependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   30 * time.Second,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -266,14 +275,14 @@ func TestNATMappingBehavior(t *testing.T) {
 		}
 
 		oic := newChunkUDP(src, dst)
-		log.Debugf("o-original  : %s\n", oic.String())
+		log.Debugf("o-original  : %s", oic.String())
 
 		oec, err := nat.translateOutbound(oic)
 		assert.Nil(t, err, "should succeed")
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-translated: %s", oec.String())
 
 		// sending different (IP: 5.6.7.9) won't create a new mapping
 		oic2 := newChunkUDP(&net.UDPAddr{
@@ -287,8 +296,9 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.Nil(t, err, "should succeed")
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
-		log.Debugf("o-translated: %s\n", oec2.String())
+		log.Debugf("o-translated: %s", oec2.String())
 
+		//nolint:forcetypeassert
 		iec := newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -300,13 +310,14 @@ func TestNATMappingBehavior(t *testing.T) {
 			},
 		)
 
-		log.Debugf("i-original  : %s\n", iec.String())
+		log.Debugf("i-original  : %s", iec.String())
 
 		iic, err := nat.translateInbound(iec)
 		assert.Nil(t, err, "should succeed")
 
-		log.Debugf("i-translated: %s\n", iic.String())
+		log.Debugf("i-translated: %s", iic.String())
 
+		//nolint:forcetypeassert
 		assert.Equal(t,
 			oic.SourceAddr().String(),
 			iic.(*chunkUDP).DestinationAddr().String(),
@@ -314,6 +325,7 @@ func TestNATMappingBehavior(t *testing.T) {
 
 		// packet with dest addr that does not exist in the mapping table
 		// will be dropped
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -329,6 +341,7 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.NotNil(t, err, "should fail (dropped)")
 
 		// packet from different port will be dropped (port-restricted-cone)
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -343,7 +356,8 @@ func TestNATMappingBehavior(t *testing.T) {
 		_, err = nat.translateInbound(iec)
 		assert.NotNil(t, err, "should fail (dropped)")
 
-		// packet from different addr will be droped (restricted-cone)
+		// packet from different addr will be dropped (restricted-cone)
+		//nolint:forcetypeassert
 		iec = newChunkUDP(
 			&net.UDPAddr{
 				IP:   net.ParseIP("6.6.6.6"),
@@ -364,7 +378,7 @@ func TestNATMappingBehavior(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointAddrDependent,
 				FilteringBehavior: EndpointAddrDependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   30 * time.Second,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -405,9 +419,9 @@ func TestNATMappingBehavior(t *testing.T) {
 			},
 		)
 
-		log.Debugf("o-original  : %s\n", oic1.String())
-		log.Debugf("o-original  : %s\n", oic2.String())
-		log.Debugf("o-original  : %s\n", oic3.String())
+		log.Debugf("o-original  : %s", oic1.String())
+		log.Debugf("o-original  : %s", oic2.String())
+		log.Debugf("o-original  : %s", oic3.String())
 
 		oec1, err := nat.translateOutbound(oic1)
 		assert.Nil(t, err, "should succeed")
@@ -421,12 +435,12 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.Equal(t, 2, len(nat.outboundMap), "should match")
 		assert.Equal(t, 2, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-translated: %s\n", oec1.String())
-		log.Debugf("o-translated: %s\n", oec2.String())
-		log.Debugf("o-translated: %s\n", oec3.String())
+		log.Debugf("o-translated: %s", oec1.String())
+		log.Debugf("o-translated: %s", oec2.String())
+		log.Debugf("o-translated: %s", oec3.String())
 
-		assert.NotEqual(t, oec1.(*chunkUDP).sourcePort, oec2.(*chunkUDP).sourcePort, "should not match")
-		assert.Equal(t, oec1.(*chunkUDP).sourcePort, oec3.(*chunkUDP).sourcePort, "should match")
+		assert.NotEqual(t, oec1.(*chunkUDP).sourcePort, oec2.(*chunkUDP).sourcePort, "should not match") //nolint:forcetypeassert
+		assert.Equal(t, oec1.(*chunkUDP).sourcePort, oec3.(*chunkUDP).sourcePort, "should match")        //nolint:forcetypeassert
 	})
 
 	t.Run("symmetric NAT port dependent mapping", func(t *testing.T) { //nolint:dupl
@@ -434,7 +448,7 @@ func TestNATMappingBehavior(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointAddrPortDependent,
 				FilteringBehavior: EndpointAddrPortDependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   30 * time.Second,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -475,9 +489,9 @@ func TestNATMappingBehavior(t *testing.T) {
 			},
 		)
 
-		log.Debugf("o-original  : %s\n", oic1.String())
-		log.Debugf("o-original  : %s\n", oic2.String())
-		log.Debugf("o-original  : %s\n", oic3.String())
+		log.Debugf("o-original  : %s", oic1.String())
+		log.Debugf("o-original  : %s", oic2.String())
+		log.Debugf("o-original  : %s", oic3.String())
 
 		oec1, err := nat.translateOutbound(oic1)
 		assert.Nil(t, err, "should succeed")
@@ -491,12 +505,12 @@ func TestNATMappingBehavior(t *testing.T) {
 		assert.Equal(t, 3, len(nat.outboundMap), "should match")
 		assert.Equal(t, 3, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-translated: %s\n", oec1.String())
-		log.Debugf("o-translated: %s\n", oec2.String())
-		log.Debugf("o-translated: %s\n", oec3.String())
+		log.Debugf("o-translated: %s", oec1.String())
+		log.Debugf("o-translated: %s", oec2.String())
+		log.Debugf("o-translated: %s", oec3.String())
 
-		assert.NotEqual(t, oec1.(*chunkUDP).sourcePort, oec2.(*chunkUDP).sourcePort, "should not match")
-		assert.NotEqual(t, oec1.(*chunkUDP).sourcePort, oec3.(*chunkUDP).sourcePort, "should match")
+		assert.NotEqual(t, oec1.(*chunkUDP).sourcePort, oec2.(*chunkUDP).sourcePort, "should not match") //nolint:forcetypeassert
+		assert.NotEqual(t, oec1.(*chunkUDP).sourcePort, oec3.(*chunkUDP).sourcePort, "should match")     //nolint:forcetypeassert
 	})
 }
 
@@ -509,7 +523,7 @@ func TestNATMappingTimeout(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointIndependent,
 				FilteringBehavior: EndpointIndependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   100 * time.Millisecond,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -533,11 +547,11 @@ func TestNATMappingTimeout(t *testing.T) {
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-original  : %s\n", oic.String())
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-original  : %s", oic.String())
+		log.Debugf("o-translated: %s", oec.String())
 
 		// record mapped addr
-		mapped := oec.(*chunkUDP).SourceAddr().String()
+		mapped := oec.(*chunkUDP).SourceAddr().String() //nolint:forcetypeassert
 
 		time.Sleep(75 * time.Millisecond)
 
@@ -547,10 +561,10 @@ func TestNATMappingTimeout(t *testing.T) {
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-original  : %s\n", oic.String())
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-original  : %s", oic.String())
+		log.Debugf("o-translated: %s", oec.String())
 
-		assert.Equal(t, mapped, oec.(*chunkUDP).SourceAddr().String(), "mapped addr should match")
+		assert.Equal(t, mapped, oec.(*chunkUDP).SourceAddr().String(), "mapped addr should match") //nolint:forcetypeassert
 
 		// sleep long enough for the mapping to expire
 		time.Sleep(125 * time.Millisecond)
@@ -561,10 +575,10 @@ func TestNATMappingTimeout(t *testing.T) {
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-original  : %s\n", oic.String())
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-original  : %s", oic.String())
+		log.Debugf("o-translated: %s", oec.String())
 
-		assert.NotEqual(t, mapped, oec.(*chunkUDP).SourceAddr().String(), "mapped addr should not match")
+		assert.NotEqual(t, mapped, oec.(*chunkUDP).SourceAddr().String(), "mapped addr should not match") //nolint:forcetypeassert
 	})
 
 	t.Run("outbound detects timeout", func(t *testing.T) {
@@ -572,7 +586,7 @@ func TestNATMappingTimeout(t *testing.T) {
 			natType: NATType{
 				MappingBehavior:   EndpointIndependent,
 				FilteringBehavior: EndpointIndependent,
-				Hairpining:        false,
+				Hairpinning:       false,
 				MappingLifeTime:   100 * time.Millisecond,
 			},
 			mappedIPs:     []net.IP{net.ParseIP(demoIP)},
@@ -596,12 +610,13 @@ func TestNATMappingTimeout(t *testing.T) {
 		assert.Equal(t, 1, len(nat.outboundMap), "should match")
 		assert.Equal(t, 1, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-original  : %s\n", oic.String())
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-original  : %s", oic.String())
+		log.Debugf("o-translated: %s", oec.String())
 
 		// sleep long enough for the mapping to expire
 		time.Sleep(125 * time.Millisecond)
 
+		//nolint:forcetypeassert
 		iec := newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -613,7 +628,7 @@ func TestNATMappingTimeout(t *testing.T) {
 			},
 		)
 
-		log.Debugf("i-original  : %s\n", iec.String())
+		log.Debugf("i-original  : %s", iec.String())
 
 		_, err = nat.translateInbound(iec)
 		assert.NotNil(t, err, "should drop")
@@ -622,7 +637,7 @@ func TestNATMappingTimeout(t *testing.T) {
 	})
 }
 
-func TestNAT1To1Bahavior(t *testing.T) {
+func TestNAT1To1Behavior(t *testing.T) {
 	loggerFactory := logging.NewDefaultLoggerFactory()
 	log := loggerFactory.NewLogger("test")
 
@@ -655,11 +670,12 @@ func TestNAT1To1Bahavior(t *testing.T) {
 		assert.Equal(t, 0, len(nat.outboundMap), "should match")
 		assert.Equal(t, 0, len(nat.inboundMap), "should match")
 
-		log.Debugf("o-original  : %s\n", oic.String())
-		log.Debugf("o-translated: %s\n", oec.String())
+		log.Debugf("o-original  : %s", oic.String())
+		log.Debugf("o-translated: %s", oec.String())
 
 		assert.Equal(t, "1.2.3.4:1234", oec.SourceAddr().String(), "should match")
 
+		//nolint:forcetypeassert
 		iec := newChunkUDP(
 			&net.UDPAddr{
 				IP:   dst.IP,
@@ -671,12 +687,12 @@ func TestNAT1To1Bahavior(t *testing.T) {
 			},
 		)
 
-		log.Debugf("i-original  : %s\n", iec.String())
+		log.Debugf("i-original  : %s", iec.String())
 
 		iic, err := nat.translateInbound(iec)
 		assert.Nil(t, err, "should succeed")
 
-		log.Debugf("i-translated: %s\n", iic.String())
+		log.Debugf("i-translated: %s", iic.String())
 
 		assert.Equal(t,
 			oic.SourceAddr().String(),
