@@ -14,7 +14,7 @@ import (
 var errNoAddress = errors.New("there must be one address")
 
 type dummyNIC struct {
-	Net
+	*Net
 	onInboundChunkHandler func(Chunk)
 }
 
@@ -38,7 +38,7 @@ func getIPAddr(n NIC) (string, error) {
 		return "", errNoAddress
 	}
 
-	return addrs[0].(*net.IPNet).IP.String(), nil
+	return addrs[0].(*net.IPNet).IP.String(), nil //nolint:forcetypeassert
 }
 
 func TestRouterStandalone(t *testing.T) {
@@ -50,8 +50,10 @@ func TestRouterStandalone(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
-		assert.Nil(t, err, "should succeed")
 		assert.Equal(t, "1.2.3.0", r.ipv4Net.IP.String(), "ip should match")
 		assert.Equal(t, "ffffff00", r.ipv4Net.Mask.String(), "mask should match")
 	})
@@ -61,7 +63,9 @@ func TestRouterStandalone(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		for i := 1; i < 255; i++ {
 			ip, err2 := r.assignIPAddress()
@@ -81,23 +85,28 @@ func TestRouterStandalone(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
-		nic := NewNet(&NetConfig{})
-		assert.NotNil(t, nic, "should succeed")
+		nic, err := NewNet(&NetConfig{})
+		if !assert.NoError(t, err, "should succeed") {
+			return
+		}
 
 		err = r.AddNet(nic)
 		assert.Nil(t, err, "should succeed")
 
 		// Now, eth0 must have one address assigned
-		eth0, err := nic.v.getInterface("eth0")
+		eth0, err := nic.getInterface("eth0")
 		assert.Nil(t, err, "should succeed")
+
 		addrs, err := eth0.Addrs()
 		assert.Nil(t, err, "should succeed")
 		assert.Equal(t, 1, len(addrs), "should match")
 		assert.Equal(t, "ip+net", addrs[0].Network(), "should match")
 		assert.Equal(t, "1.2.3.1/24", addrs[0].String(), "should match")
-		assert.Equal(t, "1.2.3.1", addrs[0].(*net.IPNet).IP.String(), "should match")
+		assert.Equal(t, "1.2.3.1", addrs[0].(*net.IPNet).IP.String(), "should match") //nolint:forcetypeassert
 	})
 
 	t.Run("AddChildRouter", func(t *testing.T) {
@@ -105,7 +114,9 @@ func TestRouterStandalone(t *testing.T) {
 			CIDR:          "0.0.0.0/0",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		r2, err := NewRouter(&RouterConfig{
 			CIDR: "192.168.0.0/24",
@@ -115,7 +126,9 @@ func TestRouterStandalone(t *testing.T) {
 
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		err = r1.AddNet(r2)
 		assert.Nil(t, err, "should succeed")
@@ -131,17 +144,21 @@ func TestRouterStandalone(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		nic := make([]*dummyNIC, 2)
 		ip := make([]*net.UDPAddr, 2)
 
 		for i := 0; i < 2; i++ {
-			anic := NewNet(&NetConfig{})
-			assert.NotNil(t, anic, "should succeed")
+			anic, netErr := NewNet(&NetConfig{})
+			if !assert.NoError(t, netErr, "should succeed") {
+				return
+			}
 
 			nic[i] = &dummyNIC{
-				Net: *anic,
+				Net: anic,
 			}
 
 			err2 := r.AddNet(nic[i])
@@ -153,6 +170,7 @@ func TestRouterStandalone(t *testing.T) {
 			addrs, err2 := eth0.Addrs()
 			assert.Nil(t, err2, "should succeed")
 			assert.Equal(t, 1, len(addrs), "should match")
+			//nolint:forcetypeassert
 			ip[i] = &net.UDPAddr{
 				IP:   addrs[0].(*net.IPNet).IP,
 				Port: 1111 * (i + 1),
@@ -188,17 +206,21 @@ func TestRouterStandalone(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		nic := make([]*dummyNIC, 2)
 		ip := make([]*net.UDPAddr, 2)
 
 		for i := 0; i < 2; i++ {
-			anic := NewNet(&NetConfig{})
-			assert.NotNil(t, anic, "should succeed")
+			anic, netErr := NewNet(&NetConfig{})
+			if !assert.NoError(t, netErr, "should succeed") {
+				return
+			}
 
 			nic[i] = &dummyNIC{
-				Net: *anic,
+				Net: anic,
 			}
 
 			err2 := r.AddNet(nic[i])
@@ -210,6 +232,7 @@ func TestRouterStandalone(t *testing.T) {
 			addrs, err2 := eth0.Addrs()
 			assert.Nil(t, err2, "should succeed")
 			assert.Equal(t, 1, len(addrs), "should match")
+			//nolint:forcetypeassert
 			ip[i] = &net.UDPAddr{
 				IP:   addrs[0].(*net.IPNet).IP,
 				Port: 1111 * (i + 1),
@@ -264,6 +287,7 @@ func TestRouterStandalone(t *testing.T) {
 
 		err = r.Stop()
 		assert.Nil(t, err, "should succeed")
+
 		assert.Equal(t, int32(0), atomic.LoadInt32(&nCbs0), "should be zero")
 		assert.Equal(t, int32(1), atomic.LoadInt32(&nCbs1), "should be zero")
 		assert.Equal(t, byte(2), seq, "should be the last chunk")
@@ -285,17 +309,21 @@ func TestRouterDelay(t *testing.T) {
 				MaxJitter:     maxJitter,
 				LoggerFactory: loggerFactory,
 			})
-			assert.Nil(t, err, "should succeed")
+			if !assert.Nil(t, err, "should succeed") {
+				return
+			}
 
 			nic := make([]*dummyNIC, 2)
 			ip := make([]*net.UDPAddr, 2)
 
 			for i := 0; i < 2; i++ {
-				anic := NewNet(&NetConfig{})
-				assert.NotNil(t, anic, "should succeed")
+				anic, netErr := NewNet(&NetConfig{})
+				if !assert.NoError(t, netErr, "should succeed") {
+					return
+				}
 
 				nic[i] = &dummyNIC{
-					Net: *anic,
+					Net: anic,
 				}
 
 				err2 := r.AddNet(nic[i])
@@ -307,6 +335,7 @@ func TestRouterDelay(t *testing.T) {
 				addrs, err2 := eth0.Addrs()
 				assert.Nil(t, err2, "should succeed")
 				assert.Equal(t, 1, len(addrs), "should match")
+				//nolint:forcetypeassert
 				ip[i] = &net.UDPAddr{
 					IP:   addrs[0].(*net.IPNet).IP,
 					Port: 1111 * (i + 1),
@@ -371,11 +400,17 @@ func TestRouterOneChild(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
-		assert.NotNil(t, wan, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
+
+		nw, err := NewNet(&NetConfig{})
+		if !assert.NoError(t, err, "should succeed") {
+			return
+		}
 
 		wanNet := &dummyNIC{
-			Net: *NewNet(&NetConfig{}),
+			Net: nw,
 		}
 
 		err = wan.AddNet(wanNet)
@@ -383,6 +418,8 @@ func TestRouterOneChild(t *testing.T) {
 
 		// Now, eth0 must have one address assigned
 		wanIP, err := getIPAddr(wanNet)
+		assert.Nil(t, err, "should succeed")
+
 		log.Debugf("wanIP: %s", wanIP)
 
 		// LAN
@@ -390,21 +427,30 @@ func TestRouterOneChild(t *testing.T) {
 			CIDR:          "192.168.0.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
-		assert.NotNil(t, lan, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
+
+		lnw, err := NewNet(&NetConfig{})
+		if !assert.NoError(t, err, "should succeed") {
+			return
+		}
 
 		lanNet := &dummyNIC{
-			Net: *NewNet(&NetConfig{}),
+			Net: lnw,
 		}
 		err = lan.AddNet(lanNet)
 		assert.Nil(t, err, "should succeed")
 
 		// Now, eth0 must have one address assigned
 		lanIP, err := getIPAddr(lanNet)
+		assert.Nil(t, err, "should succeed")
 		log.Debugf("lanIP: %s", lanIP)
 
 		err = wan.AddRouter(lan)
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		lanNet.onInboundChunkHandler = func(c Chunk) {
 			log.Debugf("lanNet received: %s", c.String())
@@ -415,10 +461,10 @@ func TestRouterOneChild(t *testing.T) {
 			log.Debugf("wanNet received: %s", c.String())
 
 			// echo the chunk
-			echo := c.Clone().(*chunkUDP)
-			err = echo.setSourceAddr(c.(*chunkUDP).DestinationAddr().String())
+			echo := c.Clone().(*chunkUDP)                                      //nolint:forcetypeassert
+			err = echo.setSourceAddr(c.(*chunkUDP).DestinationAddr().String()) //nolint:forcetypeassert
 			assert.NoError(t, err, "should succeed")
-			err = echo.setDestinationAddr(c.(*chunkUDP).SourceAddr().String())
+			err = echo.setDestinationAddr(c.(*chunkUDP).SourceAddr().String()) //nolint:forcetypeassert
 			assert.NoError(t, err, "should succeed")
 
 			log.Debug("wan.push being called..")
@@ -464,8 +510,9 @@ func TestRouterStaticIPs(t *testing.T) {
 			},
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
-		assert.NotNil(t, lan, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		assert.Equal(t, 3, len(lan.staticIPs), "should be 3")
 		assert.Equal(t, "1.2.3.1", lan.staticIPs[0].String(), "should match")
@@ -484,8 +531,9 @@ func TestRouterStaticIPs(t *testing.T) {
 			StaticIP:      demoIP,
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
-		assert.NotNil(t, lan, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		assert.Equal(t, 4, len(lan.staticIPs), "should be 4")
 		assert.Equal(t, "1.2.3.1", lan.staticIPs[0].String(), "should match")
@@ -505,7 +553,6 @@ func TestRouterStaticIPs(t *testing.T) {
 			LoggerFactory: loggerFactory,
 		})
 		assert.NoError(t, err, "should succeed")
-		assert.NotNil(t, lan, "should succeed")
 
 		assert.Equal(t, 3, len(lan.staticIPs), "should be 3")
 		assert.Equal(t, "1.2.3.1", lan.staticIPs[0].String(), "should match")
@@ -558,12 +605,7 @@ func TestRouterStaticIPs(t *testing.T) {
 			CIDR:          "0.0.0.0/0",
 			LoggerFactory: loggerFactory,
 		})
-		if !assert.NoError(t, err, "should succeed") {
-			return
-		}
-		if !assert.NotNil(t, wan, "should succeed") {
-			return
-		}
+		assert.NoError(t, err, "should succeed")
 
 		lan, err := NewRouter(&RouterConfig{
 			CIDR: "192.168.0.0/24",
@@ -577,12 +619,7 @@ func TestRouterStaticIPs(t *testing.T) {
 			},
 			LoggerFactory: loggerFactory,
 		})
-		if !assert.NoError(t, err, "should succeed") {
-			return
-		}
-		if !assert.NotNil(t, lan, "should succeed") {
-			return
-		}
+		assert.NoError(t, err, "should succeed")
 
 		err = wan.AddRouter(lan)
 		if !assert.NoError(t, err, "should succeed") {
@@ -613,7 +650,9 @@ func TestRouterFailures(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		err = r.Stop()
 		assert.Error(t, err, "should fail")
@@ -624,14 +663,18 @@ func TestRouterFailures(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
-		nic := NewNet(&NetConfig{
+		nic, err := NewNet(&NetConfig{
 			StaticIPs: []string{
 				"5.6.7.8", // out of parent router'c CIDR
 			},
 		})
-		assert.NotNil(t, nic, "should succeed")
+		if !assert.NoError(t, err, "should succeed") {
+			return
+		}
 
 		err = r.AddNet(nic)
 		assert.Error(t, err, "should fail")
@@ -642,7 +685,9 @@ func TestRouterFailures(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		r2, err := NewRouter(&RouterConfig{
 			CIDR: "192.168.0.0/24",
@@ -652,7 +697,9 @@ func TestRouterFailures(t *testing.T) {
 
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		err = r1.AddRouter(r2)
 		assert.Error(t, err, "should fail")
@@ -663,7 +710,9 @@ func TestRouterFailures(t *testing.T) {
 			CIDR:          "1.2.3.0/24",
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		r2, err := NewRouter(&RouterConfig{
 			CIDR: "192.168.0.0/24",
@@ -673,7 +722,9 @@ func TestRouterFailures(t *testing.T) {
 
 			LoggerFactory: loggerFactory,
 		})
-		assert.Nil(t, err, "should succeed")
+		if !assert.Nil(t, err, "should succeed") {
+			return
+		}
 
 		err = r1.AddChildRouter(r2)
 		assert.Error(t, err, "should fail")
